==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/portuguesebr/main.php <==
<?php /* Brazilian Portuguese Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {


// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:29
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina de impresso");
define("_MD_SENDSTORY","Enviar esta notcia  um amigo");
define("_MD_READMORE","Continuar lendo...");
define("_MD_COMMENTS","0 comentrios");
define("_MD_ONECOMMENT","1 comentrio");
define("_MD_BYTESMORE","%s bytes restantes");
define("_MD_NUMCOMMENTS","%s comentrios");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar uma notcia");
define("_MD_TITLE","Assunto");
define("_MD_TOPIC","Categoria");
define("_MD_THESCOOP","Texto");
define("_MD_NOTIFYPUBLISH","Avisar-me se esta notcia for aprovada");
define("_MD_POST","Postar");
define("_MD_GO","Enviar");
define("_MD_THANKS","Seu post foi recebido. Aguarde at que ele seja aprovado e definitivamente publicado pelo staff do site."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Obrigado por seu post.");

define("_MD_NOTIFYSBJCT","NOTCIAS no meu site"); // Notification mail subject
define("_MD_NOTIFYMSG","Uma nova notcia foi enviada."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Arquivo de notcias");
define("_MD_ARTICLES","Notcias");
define("_MD_VIEWS","hits");
define("_MD_DATE","Data de postagem");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina de impresso");
define("_MD_THEREAREINTOTAL","H, no total, %s notcias.");

// %s is your site name
define("_MD_INTARTICLE","Uma notcia interessante que encontrei em %s");
define("_MD_INTARTFOUND","Abaixo, voc tem uma notcia muito interessante que encontrei em %s:");

define("_MD_TOPICC","Categoria:");
define("_MD_URL","Endereo:");
define("_MD_NOSTORY","A notcia escolhida no existe.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","Endereo para esta notcia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Voc pode ler mais notcias em %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Notcias expiradas");
define("_AM_EXPIRED","Expirado");
define("_AM_CHANGEEXPDATETIME","Alterar data de validade");
define("_AM_SETEXPDATETIME","Definir data de validade");
define("_AM_NOWSETEXPTIME","Data de validade atual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No h nenhum arquivo.");
define("_MD_THANKS_BUT_ERROR", "Obrigado pelo seu post. Entretanto, devido  um <span style=\"color:red\">erro</span>, sua notcia no foi publicada. Pedimos desculpas pelos transtornos, e que voc contate um administrador.");
define("_MD_USE_HTML","Ativar HTML");
define("_MD_USE_SMILEY","Ativar emoticons");
define("_MD_USE_BR","Ativar quebra-linha automtica");
define("_MD_USE_XCODE","Ativar XOOPS Code");
define("_MD_JANUARY", "Janeiro");
define("_MD_FEBRUARY", "Fevereiro");
define("_MD_MARCH", "Maro");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Maio");
define("_MD_JUNE", "Junho");
define("_MD_JULY", "Julho");
define("_MD_AUGUST", "Agosto");
define("_MD_SEPTEMBER", "Setembro");
define("_MD_OCTOBER", "Outubro");
define("_MD_NOVEMBER", "Novembro");
define("_MD_DECEMBER", "Dezembro");
define("_MD_NO_TOPICS","No h nenhuma categoria.");

// ver 1.01 added
define("_MD_RSS", "RSS");

}
?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/portuguesebr/main.php <==
<?php /* Brazilian Portuguese Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {



// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:55
define('_MD_INPUTHELPER','Input Helper ON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK Editor ON/OFF (Note: Each of editors don&#039;t share the text)');
define('_MD_ERROR_REQUIRED','{0} is a required field.');

// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:29
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina de impresso");
define("_MD_SENDSTORY","Enviar esta notcia  um amigo");
define("_MD_READMORE","Continuar lendo...");
define("_MD_COMMENTS","0 comentrios");
define("_MD_ONECOMMENT","1 comentrio");
define("_MD_BYTESMORE","%s bytes restantes");
define("_MD_NUMCOMMENTS","%s comentrios");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar uma notcia");
define("_MD_TITLE","Assunto");
define("_MD_TOPIC","Categoria");
define("_MD_THESCOOP","Texto");
define("_MD_NOTIFYPUBLISH","Avisar-me se esta notcia for aprovada");
define("_MD_POST","Postar");
define("_MD_GO","Enviar");
define("_MD_THANKS","Seu post foi recebido. Aguarde at que ele seja aprovado e definitivamente publicado pelo staff do site."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Obrigado por seu post.");

define("_MD_NOTIFYSBJCT","NOTCIAS no meu site"); // Notification mail subject
define("_MD_NOTIFYMSG","Uma nova notcia foi enviada."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Arquivo de notcias");
define("_MD_ARTICLES","Notcias");
define("_MD_VIEWS","hits");
define("_MD_DATE","Data de postagem");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina de impresso");
define("_MD_THEREAREINTOTAL","H, no total, %s notcias.");

// %s is your site name
define("_MD_INTARTICLE","Uma notcia interessante que encontrei em %s");
define("_MD_INTARTFOUND","Abaixo, voc tem uma notcia muito interessante que encontrei em %s:");

define("_MD_TOPICC","Categoria:");
define("_MD_URL","Endereo:");
define("_MD_NOSTORY","A notcia escolhida no existe.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","Endereo para esta notcia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Voc pode ler mais notcias em %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Notcias expiradas");
define("_AM_EXPIRED","Expirado");
define("_AM_CHANGEEXPDATETIME","Alterar data de validade");
define("_AM_SETEXPDATETIME","Definir data de validade");
define("_AM_NOWSETEXPTIME","Data de validade atual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No h nenhum arquivo.");
define("_MD_THANKS_BUT_ERROR", "Obrigado pelo seu post. Entretanto, devido  um <span style=\"color:red\">erro</span>, sua notcia no foi publicada. Pedimos desculpas pelos transtornos, e que voc contate um administrador.");
define("_MD_USE_HTML","Ativar HTML");
define("_MD_USE_SMILEY","Ativar emoticons");
define("_MD_USE_BR","Ativar quebra-linha automtica");
define("_MD_USE_XCODE","Ativar XOOPS Code");
define("_MD_JANUARY", "Janeiro");
define("_MD_FEBRUARY", "Fevereiro");
define("_MD_MARCH", "Maro");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Maio");
define("_MD_JUNE", "Junho");
define("_MD_JULY", "Julho");
define("_MD_AUGUST", "Agosto");
define("_MD_SEPTEMBER", "Setembro");
define("_MD_OCTOBER", "Outubro");
define("_MD_NOVEMBER", "Novembro");
define("_MD_DECEMBER", "Dezembro");
define("_MD_NO_TOPICS","No h nenhuma categoria.");

// ver 1.01 added
define("_MD_RSS", "RSS");

}
?>
